searchNodes=[{"doc":"Functions that work on sets of small integers &gt;= 0. NaturalSet is an alternative set type in Elixir emulating the MapSet interface as closely as possible, with one important limitation: every element must be a non-negative integers. Many of the NaturalSet doctests and unit tests were adapted from MapSet. NaturalSet illustrates the construction of a functional data structure from scratch, with support for streaming and the Inspect, Enumerable, and Collectable protocols. By definition, sets contain unique elements. Trying to insert a duplicate is a no-op: iex&gt; natural_set = NaturalSet.new() #NaturalSet&lt;[]&gt; iex&gt; natural_set = NaturalSet.put(natural_set, 3) #NaturalSet&lt;[3]&gt; iex&gt; natural_set |&gt; NaturalSet.put(2) |&gt; NaturalSet.put(2) #NaturalSet&lt;[2, 3]&gt; NaturalSet.new/1 accepts an enumerable of elements: iex&gt; NaturalSet.new(1..5) #NaturalSet&lt;[1, 2, 3, 4, 5]&gt; An NaturalSet is represented internally using the %NaturalSet{} struct. This struct can be used whenever there's a need to pattern match on something being an NaturalSet: iex&gt; match?(%NaturalSet{}, NaturalSet.new()) true The %NaturalSet{} struct contains a single field—bits— an integer which is used as a bit vector where each bit set to 1 represents a number present in the set. An empty set is stored as bits = 0: iex&gt; empty = NaturalSet.new() iex&gt; empty.bits 0 iex&gt; NaturalSet.member?(empty, 0) false A set containing just a 0 is stored as bits = 1, because the bit at 0 is set, so the element 0 is present: iex&gt; set_with_zero = NaturalSet.new([0]) iex&gt; set_with_zero.bits 1 iex&gt; NaturalSet.member?(set_with_zero, 0) true A set with a 2 is stored as bits = 4, because the bit at 2 is set, so the element 2 is present: iex&gt; set_with_two = NaturalSet.new([2]) iex&gt; set_with_two.bits 4 iex&gt; NaturalSet.member?(set_with_two, 2) true A set with the elements 0 and 1 is stored as bits = 3, because 3 is 0b11, so the bits at 0 and 1 are set: iex&gt; set_with_zero_and_one = NaturalSet.new([0, 1]) #NaturalSet&lt;[0, 1]&gt; iex&gt; set_with_zero_and_one.bits 3 NaturalSets can also be constructed starting from other collection-type data structures: for example, see NaturalSet.new/1 or Enum.into/2. All the content of an NaturalSet is represented by a single integer, which in Elixir is limited only by available memory. Using an integer as a bit vector allows set operations like union and intersection to be implemented using fast bitwise operators. See the source code of NaturalSet.union and NaturalSet.intersection. A bit vector is efficient only for storing sets of small integers, or high-density sets where a large percentage of the possible elements are present. The memory usage is proportional only to the largest element stored, not to the number of elements present. If the largest element in a set is 1_000_000, the raw bits will take 125_000 bytes (⅛), regardless of the number of elements in the set. This package was inspired by the intset example from chapter 6 of The Go Programming Language, by Alan. A. A. Donovan and Brian W. Kernighan.","ref":"NaturalSet.html","title":"NaturalSet","type":"module"},{"doc":"Returns a new set which is a copy of natural_set without element.Examplesiex&gt; natural_set = NaturalSet.new([1, 2, 3]) iex&gt; NaturalSet.delete(natural_set, 4) #NaturalSet&lt;[1, 2, 3]&gt; iex&gt; NaturalSet.delete(natural_set, 2) #NaturalSet&lt;[1, 3]&gt;","ref":"NaturalSet.html#delete/2","title":"NaturalSet.delete/2","type":"function"},{"doc":"Returns a new set like natural_set1 without the members of natural_set2.Examplesiex&gt; NaturalSet.difference(NaturalSet.new([1, 2]), NaturalSet.new([2, 3, 4])) #NaturalSet&lt;[1]&gt;","ref":"NaturalSet.html#difference/2","title":"NaturalSet.difference/2","type":"function"},{"doc":"Checks if natural_set1 and natural_set2 have no members in common.Examplesiex&gt; NaturalSet.disjoint?(NaturalSet.new([1, 2]), NaturalSet.new([3, 4])) true iex&gt; NaturalSet.disjoint?(NaturalSet.new([1, 2]), NaturalSet.new([2, 3])) false","ref":"NaturalSet.html#disjoint?/2","title":"NaturalSet.disjoint?/2","type":"function"},{"doc":"Checks if two sets are equal.Examplesiex&gt; NaturalSet.equal?(NaturalSet.new([1, 2]), NaturalSet.new([2, 1, 1])) true iex&gt; NaturalSet.equal?(NaturalSet.new([1, 2]), NaturalSet.new([3, 4])) false","ref":"NaturalSet.html#equal?/2","title":"NaturalSet.equal?/2","type":"function"},{"doc":"Returns a set containing only members that natural_set1 and natural_set2 have in common.Examplesiex&gt; NaturalSet.intersection(NaturalSet.new([1, 2]), NaturalSet.new([2, 3, 4])) #NaturalSet&lt;[2]&gt; iex&gt; NaturalSet.intersection(NaturalSet.new([1, 2]), NaturalSet.new([3, 4])) #NaturalSet&lt;[]&gt;","ref":"NaturalSet.html#intersection/2","title":"NaturalSet.intersection/2","type":"function"},{"doc":"Returns the number of elements in natural_set. The corresponding function in MapSet is size. This function is named length because it traverses the natural_set, so it runs in O(n) time.Exampleiex&gt; NaturalSet.length(NaturalSet.new([10, 20, 30])) 3","ref":"NaturalSet.html#length/1","title":"NaturalSet.length/1","type":"function"},{"doc":"Checks if natural_set contains element.Examplesiex&gt; NaturalSet.member?(NaturalSet.new([1, 2, 3]), 2) true iex&gt; NaturalSet.member?(NaturalSet.new([1, 2, 3]), 4) false","ref":"NaturalSet.html#member?/2","title":"NaturalSet.member?/2","type":"function"},{"doc":"Returns a new empty NaturalSet.Exampleiex&gt; NaturalSet.new() #NaturalSet&lt;[]&gt;","ref":"NaturalSet.html#new/0","title":"NaturalSet.new/0","type":"function"},{"doc":"Creates a set from an enumerable.Examplesiex&gt; NaturalSet.new([10, 5, 7]) #NaturalSet&lt;[5, 7, 10]&gt; iex&gt; NaturalSet.new(3..7) #NaturalSet&lt;[3, 4, 5, 6, 7]&gt; iex&gt; NaturalSet.new([3, 3, 3, 2, 2, 1]) #NaturalSet&lt;[1, 2, 3]&gt;","ref":"NaturalSet.html#new/1","title":"NaturalSet.new/1","type":"function"},{"doc":"Creates a set from an enumerable via the transformation function.Examplesiex&gt; NaturalSet.new([1, 3, 1], fn x -&gt; 2 * x end) #NaturalSet&lt;[2, 6]&gt;","ref":"NaturalSet.html#new/2","title":"NaturalSet.new/2","type":"function"},{"doc":"Inserts element into natural_set if natural_set doesn't already contain it.Examplesiex&gt; NaturalSet.put(NaturalSet.new([1, 2, 3]), 3) #NaturalSet&lt;[1, 2, 3]&gt; iex&gt; NaturalSet.put(NaturalSet.new([1, 2, 3]), 4) #NaturalSet&lt;[1, 2, 3, 4]&gt;","ref":"NaturalSet.html#put/2","title":"NaturalSet.put/2","type":"function"},{"doc":"Returns a stream function yielding the elements of natural_set one by one in ascending order. The stream lazily traverses the bits of the natural_set as needed.Examplesiex&gt; my_stream = NaturalSet.new([10, 5, 7]) |&gt; NaturalSet.stream iex&gt; my_stream |&gt; is_function true iex&gt; my_stream |&gt; Stream.map(&amp;(&amp;1 * 10)) |&gt; Enum.to_list [50, 70, 100]","ref":"NaturalSet.html#stream/1","title":"NaturalSet.stream/1","type":"function"},{"doc":"Checks if natural_set1's members are all contained in natural_set2.This function checks if natural_set1 is a subset of natural_set2.Examplesiex&gt; NaturalSet.subset?(NaturalSet.new([1, 2]), NaturalSet.new([1, 2, 3])) true iex&gt; NaturalSet.subset?(NaturalSet.new([1, 2, 3]), NaturalSet.new([1, 2])) false","ref":"NaturalSet.html#subset?/2","title":"NaturalSet.subset?/2","type":"function"},{"doc":"Returns a list containing all members of natural_set in ascending order.Examplesiex&gt; NaturalSet.new([2, 3, 1]) |&gt; NaturalSet.to_list [1, 2, 3]","ref":"NaturalSet.html#to_list/1","title":"NaturalSet.to_list/1","type":"function"},{"doc":"Returns a set containing all members of natural_set1 and natural_set2.Examplesiex&gt; NaturalSet.union(NaturalSet.new([1, 2]), NaturalSet.new([2, 3, 4])) #NaturalSet&lt;[1, 2, 3, 4]&gt;","ref":"NaturalSet.html#union/2","title":"NaturalSet.union/2","type":"function"}]